Welcome to poissonregime's documentation!
=========================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   modules
   issues
   contributing
   history

.. include:: ../README.rst


Logo by https://www.flaticon.com/authors/iconmark.

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
